@@ -1,5 +1,5 @@
 package ZMQ::FFI::ContextRole;
-$ZMQ::FFI::ContextRole::VERSION = '1.01';
+$ZMQ::FFI::ContextRole::VERSION = '1.02';
 use Moo::Role;
 
 # real underlying zmq ctx pointer
@@ -8,6 +8,12 @@ has _ctx => (
     default => -1,
 );
 
+# used to make sure we handle fork situations correctly
+has _pid => (
+    is      => 'ro',
+    default => $$,
+);
+
 has soname => (
     is       => 'ro',
     required => 1,
@@ -46,7 +52,7 @@ ZMQ::FFI::ContextRole
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
