@@ -1,5 +1,5 @@
 package ZMQ::FFI::SocketRole;
-$ZMQ::FFI::SocketRole::VERSION = '1.01';
+$ZMQ::FFI::SocketRole::VERSION = '1.02';
 use FFI::Platypus;
 
 use Moo::Role;
@@ -28,6 +28,12 @@ has _socket => (
     default => -1,
 );
 
+# used to make sure we handle fork situations correctly
+has _pid => (
+    is      => 'ro',
+    default => $$,
+);
+
 has sockopt_sizes => (
     is      => 'ro',
     lazy    => 1,
@@ -81,7 +87,7 @@ ZMQ::FFI::SocketRole
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
