@@ -1,5 +1,5 @@
 package ZMQ::FFI::ZMQ2::Context;
-$ZMQ::FFI::ZMQ2::Context::VERSION = '1.01';
+$ZMQ::FFI::ZMQ2::Context::VERSION = '1.02';
 use FFI::Platypus;
 use ZMQ::FFI::Util qw(zmq_soname);
 use ZMQ::FFI::Constants qw(ZMQ_STREAMER);
@@ -127,6 +127,9 @@ sub device {
 sub destroy {
     my ($self) = @_;
 
+    # don't try to cleanup context cloned from another process (fork)
+    return unless $self->_pid == $$;
+
     $self->check_error(
         'zmq_term',
         zmq_term($self->_ctx)
@@ -157,7 +160,7 @@ ZMQ::FFI::ZMQ2::Context
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
