@@ -1,5 +1,5 @@
 package ZMQ::FFI::ZMQ3::Context;
-$ZMQ::FFI::ZMQ3::Context::VERSION = '1.01';
+$ZMQ::FFI::ZMQ3::Context::VERSION = '1.02';
 use FFI::Platypus;
 use ZMQ::FFI::Util qw(zmq_soname);
 use ZMQ::FFI::Constants qw(ZMQ_IO_THREADS ZMQ_MAX_SOCKETS);
@@ -133,6 +133,9 @@ sub device {
 sub destroy {
     my ($self) = @_;
 
+    # don't try to cleanup context cloned from another process (fork)
+    return unless $self->_pid == $$;
+
     $self->check_error(
         'zmq_ctx_destroy',
         zmq_ctx_destroy($self->_ctx)
@@ -163,7 +166,7 @@ ZMQ::FFI::ZMQ3::Context
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
